@@ -29,8 +29,12 @@
 #endif
 
 
+#if EPHY_VERSION >= 227
+#include <epiphany/epiphany.h>
+#else
 #include <epiphany/ephy-embed-single.h>
 #include <epiphany/ephy-embed-shell.h>
+#endif
 
 #define EPHY_GWGET_EXTENSION_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_GWGET_EXTENSION, EphyGwgetExtensionPrivate))
 
@@ -101,8 +105,9 @@ handle_content_cb (EphyEmbedSingle *single,
 #endif
 
 #if DBUS_VERSION <= 33
-	call = dbus_g_proxy_begin_call (remote_object, "OpenURI",
+	call = dbus_g_proxy_begin_call (remote_object, "OpenURIDest",
 					DBUS_TYPE_STRING, &uri,
+					DBUS_TYPE_STRING, "",
 					DBUS_TYPE_UINT32, &timestamp,
 					DBUS_TYPE_INVALID);
 
@@ -113,8 +118,9 @@ handle_content_cb (EphyEmbedSingle *single,
 		continue;
 	}
 #elif DBUS_VERSION == 34
-	call = dbus_g_proxy_begin_call (remote_object, "OpenURI",
+	call = dbus_g_proxy_begin_call (remote_object, "OpenURIDest",
 					G_TYPE_STRING, uri,
+					G_TYPE_STRING, "",
 					G_TYPE_UINT, &timestamp,
 					G_TYPE_INVALID);
 
@@ -125,8 +131,9 @@ handle_content_cb (EphyEmbedSingle *single,
 		continue;
 	}
 #else
-	if (!dbus_g_proxy_call (remote_object, "OpenURI", &error,
+	if (!dbus_g_proxy_call (remote_object, "OpenURIDest", &error,
 				G_TYPE_STRING, uri,
+				G_TYPE_STRING, "",
 				G_TYPE_UINT, &timestamp,
 				G_TYPE_INVALID,
 				G_TYPE_INVALID)) {
