@@ -29,6 +29,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <string.h>
 #include "gwget_data.h"
 
 G_DEFINE_TYPE (GwgetApplication, gwget_application, G_TYPE_OBJECT);
@@ -61,7 +62,6 @@ gwget_application_register_service (GwgetApplication *application)
 						  DBUS_PATH_DBUS,
 						  DBUS_INTERFACE_DBUS);
 
-#if DBUS_VERSION >= 60	
 	if (!org_freedesktop_DBus_request_name (driver_proxy,
                                         	APPLICATION_SERVICE_NAME,
 						DBUS_NAME_FLAG_DO_NOT_QUEUE,
@@ -69,26 +69,13 @@ gwget_application_register_service (GwgetApplication *application)
 		g_warning ("Service registration failed.");
 		g_clear_error (&err);
 	}
-#else
-	if (!org_freedesktop_DBus_request_name (driver_proxy,
-						APPLICATION_SERVICE_NAME,
-						0, &request_name_result, &err)) {
-		g_warning ("Service registration failed.");
-		g_clear_error (&err);
-	}
-#endif	
 
 	if (request_name_result == DBUS_REQUEST_NAME_REPLY_EXISTS) {
 		return FALSE;
 	}
 
-#if DBUS_VERSION == 33
-	dbus_g_object_class_install_info (G_OBJECT_GET_CLASS (application),
-					  &dbus_glib_gwget_application_object_info);
-#else
 	dbus_g_object_type_install_info (GWGET_TYPE_APPLICATION,
 					 &dbus_glib_gwget_application_object_info);
-#endif
 
 	dbus_g_connection_register_g_object (connection,
 					     "/org/gnome/gwget/Gwget",
@@ -134,14 +121,13 @@ init_session (GwgetApplication *application)
 
 gboolean
 gwget_application_open_window (GwgetApplication  *application,
-			    guint32         timestamp,
-			    GError        **error)
+                           guint32         timestamp,
+                           GError        **error)
 {
 
-	return TRUE;
+       return TRUE;
 }
 
-
 gboolean
 gwget_application_open_uri (GwgetApplication  *application,
 			 const char     *url,
@@ -149,9 +135,32 @@ gwget_application_open_uri (GwgetApplication  *application,
 			 GError        **error)
 {
 	GwgetData *gwgetdata;
+
+	gwgetdata = gwget_data_new ((gchar *)url);
+
+	gwget_data_add_download(gwgetdata);
+	gwget_data_start_download(gwgetdata);
+
+	return TRUE;
+}
+
+gboolean
+gwget_application_open_uri_with_dest (GwgetApplication  *application,
+			 const char     *url,
+			 const char	*destination_dir,
+			 guint32         timestamp,
+			 GError        **error)
+{
+	GwgetData *gwgetdata;
 	
+	gwgetdata = gwget_data_new ((gchar *)url);
+	
+	if (strlen(destination_dir)!=0) {
+		gwgetdata->dir = (gchar *)destination_dir;
+        } else {
+        	gwgetdata->dir = gwget_pref.download_dir;
+        }
 	
-	gwgetdata = gwget_data_create ((gchar *)url, gwget_pref.download_dir);
 	gwget_data_add_download(gwgetdata);
 	gwget_data_start_download(gwgetdata);
 
